{ pkgs, ... }:

let
 musnix_channel = (fetchTarball "https://github.com/musnix/musnix/archive/master.tar.gz");
# vaapiIntel = pkgs.vaapiIntel.override { enableHybridCodec = true; };
in {
  imports = [ <nixpkgs/nixos/modules/installer/scan/not-detected.nix>
              musnix_channel ];

  musnix = {
    enable = true;
    alsaSeq.enable = true;
    ffado.enable = true;
    soundcardPciId = "00:14.0";
    kernel.realtime = true;
    kernel.packages = pkgs.linuxPackages_4_19_rt;
    rtirq.enable = true;
  };

  boot = {
    loader.systemd-boot.enable = true;
    loader.efi.canTouchEfiVariables = true;
    cleanTmpDir = true;
#    kernelPackages = pkgs.linuxPackages_4_19;

    initrd.kernelModules = [ "hid-multitouch" ];
    initrd.availableKernelModules = [ "hid-microsoft" "hid-multitouch" "xhci_pci" "nvme" "usb_storage" "sd_mod" ];
    kernelModules = [ "kvm-intel" "hid-microsoft" "hid-multitouch" "uinput" ];
    kernel.sysctl = { "fs.inotify.max_user_watches" = 524288; };
    kernelParams = [ "threadirq" ];
    extraModulePackages = [ ];
  };

  fileSystems."/" =
    { device = "/dev/disk/by-uuid/8c3a5a07-9ee1-4154-9f3f-6abc379073aa";
      fsType = "ext4";
      options = [ "noatime" ];
    };

  fileSystems."/boot" =
    { device = "/dev/disk/by-uuid/D2A2-C705";
      fsType = "vfat";
    };

  swapDevices = [ ];

  hardware = {
    firmware = with pkgs; [ firmwareLinuxNonfree firmware_surface ];
    cpu.intel.updateMicrocode = true;
    enableAllFirmware = true;
    enableKSM = true;
    opengl = {
      driSupport = true;
      extraPackages = with pkgs; [ intel-media-driver libvdpau-va-gl vaapiIntel vaapiVdpau intel-media-driver ];
      driSupport32Bit = true;
      extraPackages32 = with pkgs.pkgsi686Linux; [ libvdpau-va-gl vaapiIntel vaapiVdpau ];
    };

    pulseaudio = {
      enable = true;
      support32Bit = true;
      package = pkgs.pulseaudioFull;
      zeroconf.discovery.enable = false;
      extraClientConf = ''
        autospawn = no
      '';
    };

    bluetooth = {
      enable = true;
      powerOnBoot = true;
    };
  };

  powerManagement = {
    enable = true;
    # cpuFreqGovernor = "powersave";
  };
  services.upower.enable = true;

  time.timeZone = "Europe/Berlin";
}
